==> dif-database-repository-2.3.9-17-sources.jar: pt/digitalis/dif/dem/managers/impl/model/data/Groups.java <==
package pt.digitalis.dif.dem.managers.impl.model.data;


import java.util.ArrayList;
import java.util.HashSet;
import java.util.List;
import java.util.Set;
import pt.digitalis.dif.model.utils.AbstractBeanRelationsAttributes;

/**
 * Groups
 * Generated on ORM Generator
 * DIF build process for the Model layer
 *
 */
@SuppressWarnings("serial")
public class Groups extends AbstractBeanRelationsAttributes implements java.io.Serializable {

    /** Groups attributes enumeration */
    public static class Fields {
        /** id column */
        public static final String ID = "id";
        /** name column */
        public static final String NAME = "name";
        /** description column */
        public static final String DESCRIPTION = "description";
        /** defaultGroup column */
        public static final String DEFAULTGROUP = "defaultGroup";

	    /**
          * List of existing fields
	     *
	     * @return list of field names
	     */
        public static List<String> values() {
            ArrayList<String> list = new ArrayList<String>();
            list.add("id");
            list.add("name");
            list.add("description");
            list.add("defaultGroup");

            return list;
        }
    }

	/**
 	 * The Class Relations.
 	 */
	 public class Relations extends AbstractBeanRelationsAttributes.AbstractRelations {

        /**
         * Instantiates a new relations.
         *
         * @param currentPath
         *            the current path
         */
        public Relations(String currentPath)
        {
            super(currentPath);
        }
        /**
         * groups relation.
         *
         * @return the groups bean relations attributes.
         */
        public Groups.Relations groups()
        {
			Groups c = new Groups();
            return c.new Relations(this.buildPath("groups"));
        }
        
        /**
         * userses relation.
         *
         * @return the userses bean relations attributes.
         */
        public Users.Relations userses()
        {
			Users c = new Users();
            return c.new Relations(this.buildPath("userses"));
        }
        
        /**
         * userGroupses relation.
         *
         * @return the userGroupses bean relations attributes.
         */
        public UserGroups.Relations userGroupses()
        {
			UserGroups c = new UserGroups();
            return c.new Relations(this.buildPath("userGroupses"));
        }
        
        /**
         * groupses relation.
         *
         * @return the groupses bean relations attributes.
         */
        public Groups.Relations groupses()
        {
			Groups c = new Groups();
            return c.new Relations(this.buildPath("groupses"));
        }
        
		/**
         * the ID path.
         *
         * @return the path
         */
        public String ID()
        {
            return buildPath(Fields.ID);
        }
		/**
         * the NAME path.
         *
         * @return the path
         */
        public String NAME()
        {
            return buildPath(Fields.NAME);
        }
		/**
         * the DESCRIPTION path.
         *
         * @return the path
         */
        public String DESCRIPTION()
        {
            return buildPath(Fields.DESCRIPTION);
        }
		/**
         * the DEFAULTGROUP path.
         *
         * @return the path
         */
        public String DEFAULTGROUP()
        {
            return buildPath(Fields.DEFAULTGROUP);
        }
    }
	
	/** The dummy obj. */
    private static Groups dummyObj = new Groups();

	/**
     * Get Groups Relations .
     *
     * @return the relations
     */
    public static Relations FK()
    {
        return dummyObj.new Relations(null);
    }

    /**
     * @see pt.digitalis.dif.model.utils.AbstractBeanAttributes#getAttributeNoGraphNavigation(java.lang.String)
     */
    @Override
    protected Object getAttributeNoGraphNavigation(String attributeName) {

        if ("id".equalsIgnoreCase(attributeName))
            return id;
        if ("groups".equalsIgnoreCase(attributeName))
            return groups;
        if ("name".equalsIgnoreCase(attributeName))
            return name;
        if ("description".equalsIgnoreCase(attributeName))
            return description;
        if ("defaultGroup".equalsIgnoreCase(attributeName))
            return defaultGroup;
        if ("userses".equalsIgnoreCase(attributeName))
            return userses;
        if ("userGroupses".equalsIgnoreCase(attributeName))
            return userGroupses;
        if ("groupses".equalsIgnoreCase(attributeName))
            return groupses;

        return null;
    }

    /**
     * @see pt.digitalis.utils.common.IBeanAttributes#setAttribute(java.lang.String, java.lang.Object)
     */
    @SuppressWarnings("all")
    public void setAttribute(String attributeName, Object attributeValue) {

        if ("id".equalsIgnoreCase(attributeName))
            id = (String)attributeValue;
        if ("groups".equalsIgnoreCase(attributeName))
            groups = (Groups)attributeValue;
        if ("name".equalsIgnoreCase(attributeName))
            name = (String)attributeValue;
        if ("description".equalsIgnoreCase(attributeName))
            description = (String)attributeValue;
        if ("defaultGroup".equalsIgnoreCase(attributeName))
            defaultGroup = (Boolean)attributeValue;
        if ("userses".equalsIgnoreCase(attributeName))
            userses = (Set<Users>)attributeValue;
        if ("userGroupses".equalsIgnoreCase(attributeName))
            userGroupses = (Set<UserGroups>)attributeValue;
        if ("groupses".equalsIgnoreCase(attributeName))
            groupses = (Set<Groups>)attributeValue;
    }

    // Fields

    /** id private attribute */
    private String id;

    /** groups private attribute */
    private Groups groups;

    /** name private attribute */
    private String name;

    /** description private attribute */
    private String description;

    /** defaultGroup private attribute */
    private boolean defaultGroup;

    /** userses private attribute */
    private Set<Users> userses = new HashSet<Users>(0);

    /** userGroupses private attribute */
    private Set<UserGroups> userGroupses = new HashSet<UserGroups>(0);

    /** groupses private attribute */
    private Set<Groups> groupses = new HashSet<Groups>(0);

    /** The pojo's primary key field list names */
    private static List<String> pkFieldList;

    /**
     * Get the table fields that compose the PK
     *
     * @return the PK field list
     */
     public synchronized static List<String> getPKFieldList()
     {
         if (pkFieldList == null)
         {
             pkFieldList = new ArrayList<String>();
             pkFieldList.add("id");
         }

         return pkFieldList;
     }

    /**
     * Get the table fields that compose the PK as a comma separated field name list
     *
     * @return the PK field list as a string
     */
     public static String getPKFieldListAsString()
     {
         StringBuffer buffer = new StringBuffer();

         for (int i = 0; i < getPKFieldList().size(); i++)
         {
             if (i != 0)
                 buffer.append(",");

             buffer.append(getPKFieldList().get(i));
         }

         return buffer.toString();
     }

    /**
     * @see pt.digitalis.dif.model.utils.AbstractBeanAttributes#getAttributeAsString(java.lang.String)
     */
     @Override
     public String getAttributeAsString(String attributeName)
     {

        Object value = getAttribute(attributeName);

        if (value == null)
            return "";
        else {
            return value.toString().trim();
        }
     }

    // Constructors

    /**
     * default constructor
     */
    public Groups() {
    }

	/** 
	 * minimal constructor
	 *
     * @param id
     * @param name
     * @param defaultGroup
    }
	 */
    public Groups(String id, String name, boolean defaultGroup) {
        this.id = id;
        this.name = name;
        this.defaultGroup = defaultGroup;
    }

    /**
     * full constructor
	 *
     * @param id
     * @param groups
     * @param name
     * @param description
     * @param defaultGroup
     * @param userses
     * @param userGroupses
     * @param groupses
     */
    public Groups(String id, Groups groups, String name, String description, boolean defaultGroup, Set<Users> userses, Set<UserGroups> userGroupses, Set<Groups> groupses) {
        this.id = id;
        this.groups = groups;
        this.name = name;
        this.description = description;
        this.defaultGroup = defaultGroup;
        this.userses = userses;
        this.userGroupses = userGroupses;
        this.groupses = groupses;
    }

    // Property accessors
    
    /**       
     * id getter method
     *
     * @return id method
     */
    public String getId() {
        return this.id;
    }
    
    /**       
     * id setter method
     *
     * @param id
     *
     * @return Groups modified instance
     */
    public Groups setId(String id) {
        this.id = id;
        
        return this;
    }
    /**       
     * groups getter method
     *
     * @return groups method
     */
    public Groups getGroups() {
        return this.groups;
    }
    
    /**       
     * groups setter method
     *
     * @param groups
     *
     * @return Groups modified instance
     */
    public Groups setGroups(Groups groups) {
        this.groups = groups;
        
        return this;
    }
    /**       
     * name getter method
     *
     * @return name method
     */
    public String getName() {
        return this.name;
    }
    
    /**       
     * name setter method
     *
     * @param name
     *
     * @return Groups modified instance
     */
    public Groups setName(String name) {
        this.name = name;
        
        return this;
    }
    /**       
     * description getter method
     *
     * @return description method
     */
    public String getDescription() {
        return this.description;
    }
    
    /**       
     * description setter method
     *
     * @param description
     *
     * @return Groups modified instance
     */
    public Groups setDescription(String description) {
        this.description = description;
        
        return this;
    }
    /**       
     * defaultGroup getter method
     *
     * @return defaultGroup method
     */
    public boolean isDefaultGroup() {
        return this.defaultGroup;
    }
    
    /**       
     * defaultGroup setter method
     *
     * @param defaultGroup
     *
     * @return Groups modified instance
     */
    public Groups setDefaultGroup(boolean defaultGroup) {
        this.defaultGroup = defaultGroup;
        
        return this;
    }
    /**       
     * userses getter method
     *
     * @return userses method
     */
    public Set<Users> getUserses() {
        return this.userses;
    }
    
    /**       
     * userses setter method
     *
     * @param userses
     *
     * @return Groups modified instance
     */
    public Groups setUserses(Set<Users> userses) {
        this.userses = userses;
        
        return this;
    }
    /**       
     * userGroupses getter method
     *
     * @return userGroupses method
     */
    public Set<UserGroups> getUserGroupses() {
        return this.userGroupses;
    }
    
    /**       
     * userGroupses setter method
     *
     * @param userGroupses
     *
     * @return Groups modified instance
     */
    public Groups setUserGroupses(Set<UserGroups> userGroupses) {
        this.userGroupses = userGroupses;
        
        return this;
    }
    /**       
     * groupses getter method
     *
     * @return groupses method
     */
    public Set<Groups> getGroupses() {
        return this.groupses;
    }
    
    /**       
     * groupses setter method
     *
     * @param groupses
     *
     * @return Groups modified instance
     */
    public Groups setGroupses(Set<Groups> groupses) {
        this.groupses = groupses;
        
        return this;
    }

    /**
     * Creates a String representation of the Groups object
     *
     * @return the compiled String
     */
    @Override
    public String toString() {
	    StringBuffer buffer = new StringBuffer();

        buffer.append(getClass().getName()).append("@").append(Integer.toHexString(hashCode())).append(" [");

        buffer.append("id").append("='").append(getId()).append("' ");			
        buffer.append("name").append("='").append(getName()).append("' ");			
        buffer.append("description").append("='").append(getDescription()).append("' ");			
        buffer.append("defaultGroup").append("='").append(isDefaultGroup()).append("' ");			
        buffer.append("]");
      
        return buffer.toString();
    }

    /**
     * Compares the String representation of the Groups object
     *
     * @param other The object to compare to
     *
     * @return true of the objects are equal
     */
    public boolean equals(Groups other) {
        	return this.toString().equals(other.toString());
    }
    /**
     * @see pt.digitalis.utils.common.IBeanAttributes#setAttributeFromString(java.lang.String, java.lang.String)
     */
    public void setAttributeFromString(String attributeName, String attributeValue) {
        if ("id".equalsIgnoreCase(attributeName))
        	this.id = attributeValue;

        if ("name".equalsIgnoreCase(attributeName))
        	this.name = attributeValue;

        if ("description".equalsIgnoreCase(attributeName))
        	this.description = attributeValue;

        if ("defaultGroup".equalsIgnoreCase(attributeName))
            this.defaultGroup = Boolean.valueOf(attributeValue);

    }


}

==> dif-database-repository-2.7.1-sources.jar: pt/digitalis/dif/dem/managers/impl/model/data/Groups.java <==
package pt.digitalis.dif.dem.managers.impl.model.data;


import java.util.ArrayList;
import java.util.HashSet;
import java.util.List;
import java.util.Set;
import org.hibernate.Session;
import pt.digitalis.dif.model.dataset.HibernateDataSet;
import pt.digitalis.dif.model.dataset.IDataSet;
import pt.digitalis.dif.model.hibernate.HibernateUtil;
import pt.digitalis.dif.model.utils.AbstractBeanRelationsAttributes;
import pt.digitalis.dif.model.utils.IBeanAttributesDataSet;

/**
 * Groups
* Generated on ORM Generator
* DIF build process for the Model layer
*
*/
@SuppressWarnings("serial")
public class Groups extends AbstractBeanRelationsAttributes implements java.io.Serializable, IBeanAttributesDataSet<Groups> {

    /** Groups attributes enumeration */
    public static class Fields
    {
        /** id column */
        public static final String ID ="id";
        /** name column */
        public static final String NAME ="name";
        /** description column */
        public static final String DESCRIPTION ="description";
        /** defaultGroup column */
        public static final String DEFAULTGROUP ="defaultGroup";

        /**
         * List of existing fields
         *
         * @return list of field names
         */
        public static List<String> values()
        {
            ArrayList<String> list = new ArrayList<String>();
            list.add("id");
            list.add("name");
            list.add("description");
            list.add("defaultGroup");

            return list;
        }
    }

    /** Field attributes */
    public static GroupsFieldAttributes FieldAttributes=new GroupsFieldAttributes();

    /**
    * @return the field attributes definitions
    */
    @Override public GroupsFieldAttributes getDefinitions()
    {
        return FieldAttributes;
    }

    /**
     * The Class Relations.
     */
    public class Relations extends AbstractBeanRelationsAttributes.AbstractRelations
    {

        /**
        * Instantiates a new relations.
        *
        * @param currentPath the current path
        */
        public Relations(String currentPath)
        {
            super(currentPath);
        }
        /**
         * groups relation.
         *
         * @return the groups bean relations attributes.
         */
        public Groups.Relations groups()
        {
            Groups c = new Groups();
            return c.new Relations(this.buildPath("groups"));
        }

        /**
         * userses relation.
         *
         * @return the userses bean relations attributes.
         */
        public Users.Relations userses()
        {
            Users c = new Users();
            return c.new Relations(this.buildPath("userses"));
        }

        /**
         * userGroupses relation.
         *
         * @return the userGroupses bean relations attributes.
         */
        public UserGroups.Relations userGroupses()
        {
            UserGroups c = new UserGroups();
            return c.new Relations(this.buildPath("userGroupses"));
        }

        /**
         * groupses relation.
         *
         * @return the groupses bean relations attributes.
         */
        public Groups.Relations groupses()
        {
            Groups c = new Groups();
            return c.new Relations(this.buildPath("groupses"));
        }

        /**
         * the ID path.
         *
         * @return the path
         */
        public String ID()
        {
            return buildPath(Fields.ID);
        }
        /**
         * the NAME path.
         *
         * @return the path
         */
        public String NAME()
        {
            return buildPath(Fields.NAME);
        }
        /**
         * the DESCRIPTION path.
         *
         * @return the path
         */
        public String DESCRIPTION()
        {
            return buildPath(Fields.DESCRIPTION);
        }
        /**
         * the DEFAULTGROUP path.
         *
         * @return the path
         */
        public String DEFAULTGROUP()
        {
            return buildPath(Fields.DEFAULTGROUP);
        }
    }

    /** The dummy obj. */
    private static Groups dummyObj=new Groups();

    /**
     * Get Groups Relations .
     *
     * @return the relations
     */
    public static Relations FK()
    {
        return dummyObj.new Relations(null);
    }

    /**
    * Gets a new dataSet object for this bean
    *
    * @return the dataSet
    */
    public IDataSet<Groups> getDataSet()
    {
        return new HibernateDataSet<Groups>(Groups.class, HibernateUtil.getSessionFactory("DIFRepository"),
            Groups.getPKFieldListAsString(), Groups.FieldAttributes);
    }

    /**
    * Gets a new dataSet object for this bean
    *
    * @return the dataSet
    */
    public static IDataSet<Groups> getDataSetInstance()
    {
        return new Groups().getDataSet();
    }

    /**
    * @see pt.digitalis.dif.model.utils.AbstractBeanAttributes#getAttributeNoGraphNavigation(java.lang.String)
    */
    @Override protected Object getAttributeNoGraphNavigation(String attributeName)
    {
        if("id".equalsIgnoreCase(attributeName))
            return id;
        if("groups".equalsIgnoreCase(attributeName))
            return groups;
        if("name".equalsIgnoreCase(attributeName))
            return name;
        if("description".equalsIgnoreCase(attributeName))
            return description;
        if("defaultGroup".equalsIgnoreCase(attributeName))
            return defaultGroup;
        if("userses".equalsIgnoreCase(attributeName))
            return userses;
        if("userGroupses".equalsIgnoreCase(attributeName))
            return userGroupses;
        if("groupses".equalsIgnoreCase(attributeName))
            return groupses;

        return null;
    }

    /**
    * @see pt.digitalis.utils.common.IBeanAttributes#setAttribute(java.lang.String, java.lang.Object)
    */
    public void setAttribute(String attributeName,Object attributeValue)
    {
        if("id".equalsIgnoreCase(attributeName))
            id =(String)attributeValue;
        if("groups".equalsIgnoreCase(attributeName))
            groups =(Groups)attributeValue;
        if("name".equalsIgnoreCase(attributeName))
            name =(String)attributeValue;
        if("description".equalsIgnoreCase(attributeName))
            description =(String)attributeValue;
        if("defaultGroup".equalsIgnoreCase(attributeName))
            defaultGroup =(Boolean)attributeValue;
        if("userses".equalsIgnoreCase(attributeName))
            userses =(Set<Users>)attributeValue;
        if("userGroupses".equalsIgnoreCase(attributeName))
            userGroupses =(Set<UserGroups>)attributeValue;
        if("groupses".equalsIgnoreCase(attributeName))
            groupses =(Set<Groups>)attributeValue;
    }

    // Fields

    /** id private attribute */
    private String id;

    /** groups private attribute */
    private Groups groups;

    /** name private attribute */
    private String name;

    /** description private attribute */
    private String description;

    /** defaultGroup private attribute */
    private boolean defaultGroup;

    /** userses private attribute */
    private Set<Users> userses = new HashSet<Users>(0);

    /** userGroupses private attribute */
    private Set<UserGroups> userGroupses = new HashSet<UserGroups>(0);

    /** groupses private attribute */
    private Set<Groups> groupses = new HashSet<Groups>(0);

    /** The pojo's primary key field list names */
    private static List<String> pkFieldList;

    /**
     * Get the table fields that compose the PK
     *
     * @return the PK field list
     */
     public synchronized static List<String> getPKFieldList()
     {
         if (pkFieldList == null)
         {
             pkFieldList = new ArrayList<String>();
             pkFieldList.add("id");
         }

         return pkFieldList;
     }

    /**
     * Get the table fields that compose the PK as a comma separated field name list
     *
     * @return the PK field list as a string
     */
     public static String getPKFieldListAsString()
     {
         StringBuffer buffer = new StringBuffer();

         for (int i = 0; i < getPKFieldList().size(); i++)
         {
             if (i != 0)
                 buffer.append(",");

             buffer.append(getPKFieldList().get(i));
         }

         return buffer.toString();
     }

    /**
     * @see pt.digitalis.dif.model.utils.AbstractBeanAttributes#getAttributeAsString(java.lang.String)
     */
     @Override
     public String getAttributeAsString(String attributeName)
     {

        Object value = getAttribute(attributeName);

        if (value == null)
            return "";
        else {
            return value.toString().trim();
        }
     }

    // Constructors

    /**
     * default constructor
     */
    public Groups() {
    }

	/** 
	 * minimal constructor
	 *
     * @param id the id
     * @param name the name
     * @param defaultGroup the defaultGroup
    }
	 */
    public Groups(String id, String name, boolean defaultGroup) {
        this.id = id;
        this.name = name;
        this.defaultGroup = defaultGroup;
    }

    /**
     * full constructor
	 *
     * @param id the id
     * @param groups the groups
     * @param name the name
     * @param description the description
     * @param defaultGroup the defaultGroup
     * @param userses the userses
     * @param userGroupses the userGroupses
     * @param groupses the groupses
     */
    public Groups(String id, Groups groups, String name, String description, boolean defaultGroup, Set<Users> userses, Set<UserGroups> userGroupses, Set<Groups> groupses) {
        this.id = id;
        this.groups = groups;
        this.name = name;
        this.description = description;
        this.defaultGroup = defaultGroup;
        this.userses = userses;
        this.userGroupses = userGroupses;
        this.groupses = groupses;
    }

    // Property accessors
    
    /**       
     * id getter method
     *
     * @return id method
     */
    public String getId() {
        return this.id;
    }
    
    /**       
     * id setter method
     *
     * @param id the id
     *
     * @return Groups modified instance
     */
    public Groups setId(String id) {
        this.id = id;
        
        return this;
    }
    /**       
     * groups getter method
     *
     * @return groups method
     */
    public Groups getGroups() {
        return this.groups;
    }
    
    /**       
     * groups setter method
     *
     * @param groups the groups
     *
     * @return Groups modified instance
     */
    public Groups setGroups(Groups groups) {
        this.groups = groups;
        
        return this;
    }
    /**       
     * name getter method
     *
     * @return name method
     */
    public String getName() {
        return this.name;
    }
    
    /**       
     * name setter method
     *
     * @param name the name
     *
     * @return Groups modified instance
     */
    public Groups setName(String name) {
        this.name = name;
        
        return this;
    }
    /**       
     * description getter method
     *
     * @return description method
     */
    public String getDescription() {
        return this.description;
    }
    
    /**       
     * description setter method
     *
     * @param description the description
     *
     * @return Groups modified instance
     */
    public Groups setDescription(String description) {
        this.description = description;
        
        return this;
    }
    /**       
     * defaultGroup getter method
     *
     * @return defaultGroup method
     */
    public boolean isDefaultGroup() {
        return this.defaultGroup;
    }
    
    /**       
     * defaultGroup setter method
     *
     * @param defaultGroup the defaultGroup
     *
     * @return Groups modified instance
     */
    public Groups setDefaultGroup(boolean defaultGroup) {
        this.defaultGroup = defaultGroup;
        
        return this;
    }
    /**       
     * userses getter method
     *
     * @return userses method
     */
    public Set<Users> getUserses() {
        return this.userses;
    }
    
    /**       
     * userses setter method
     *
     * @param userses the userses
     *
     * @return Groups modified instance
     */
    public Groups setUserses(Set<Users> userses) {
        this.userses = userses;
        
        return this;
    }
    /**       
     * userGroupses getter method
     *
     * @return userGroupses method
     */
    public Set<UserGroups> getUserGroupses() {
        return this.userGroupses;
    }
    
    /**       
     * userGroupses setter method
     *
     * @param userGroupses the userGroupses
     *
     * @return Groups modified instance
     */
    public Groups setUserGroupses(Set<UserGroups> userGroupses) {
        this.userGroupses = userGroupses;
        
        return this;
    }
    /**       
     * groupses getter method
     *
     * @return groupses method
     */
    public Set<Groups> getGroupses() {
        return this.groupses;
    }
    
    /**       
     * groupses setter method
     *
     * @param groupses the groupses
     *
     * @return Groups modified instance
     */
    public Groups setGroupses(Set<Groups> groupses) {
        this.groupses = groupses;
        
        return this;
    }

    /**
     * Creates a String representation of the Groups object
     *
     * @return the compiled String
     */
    @Override
    public String toString() {
	    StringBuffer buffer = new StringBuffer();

        buffer.append(getClass().getName()).append("@").append(Integer.toHexString(hashCode())).append(" [");

        buffer.append("id").append("='").append(getId()).append("' ");			
        buffer.append("name").append("='").append(getName()).append("' ");			
        buffer.append("description").append("='").append(getDescription()).append("' ");			
        buffer.append("defaultGroup").append("='").append(isDefaultGroup()).append("' ");			
        buffer.append("]");
      
        return buffer.toString();
    }

    /**
     * Compares the String representation of the Groups object
     *
     * @param other The object to compare to
     *
     * @return true of the objects are equal
     */
    public boolean equals(Groups other) {
        	return this.toString().equals(other.toString());
    }
    /**
     * @see pt.digitalis.utils.common.IBeanAttributes#setAttributeFromString(java.lang.String, java.lang.String)
     */
    public void setAttributeFromString(String attributeName, String attributeValue) {
        if ("id".equalsIgnoreCase(attributeName))
        	this.id = attributeValue;

        if ("name".equalsIgnoreCase(attributeName))
        	this.name = attributeValue;

        if ("description".equalsIgnoreCase(attributeName))
        	this.description = attributeValue;

        if ("defaultGroup".equalsIgnoreCase(attributeName))
            this.defaultGroup = Boolean.valueOf(attributeValue);

    }


    /**
     * Instanciates an Hibernate proxy data object (does not load it from the database, provides lazy load for that)
     *
     * @param session the session
     * @param id      the id
     *
     * @return the proxy
     */
    public static Groups getProxy(Session session, String id)
    {
        return(Groups)session.load(Groups.class,id);
    }

    /**
    * Instanciates an Hibernate proxy data object (does not load it from the database, provides lazy load for that)
    *
    * @param id      the id
    *
    * @return the proxy
    */
    public static Groups getProxy(String id)
    {
        Session session = HibernateUtil.getSessionFactory("DIFRepository").getCurrentSession();
        boolean wasActive = session.getTransaction().isActive();

        if (!wasActive)
            session.beginTransaction();

        Groups result = (Groups)session.load(Groups.class,id);

        if (!wasActive)
            session.getTransaction().commit();

        return result;
    }


    /**
     * Instanciates an Hibernate data object
     *
     * @param session the session
     * @param id      the id
     *
     * @return the instance
     */
    public static Groups getInstance(Session session, String id)
    {
        return(Groups)session.get(Groups.class,id);
    }

    /**
    * Instanciates an Hibernate data object
    *
    * @param id      the id
    *
    * @return the instance
    */
    public static Groups getInstance(String id)
    {
        Session session = HibernateUtil.getSessionFactory("DIFRepository").getCurrentSession();
        boolean wasActive = session.getTransaction().isActive();

        if (!wasActive)
            session.beginTransaction();

        Groups result = (Groups)session.get(Groups.class,id);

        if (!wasActive)
            session.getTransaction().commit();

        return result;
    }

}
